@@ -6,38 +6,56 @@
  * Descr.: GNU Prolog - general header file (for users)                    *
  * Author: Daniel Diaz                                                     *
  *                                                                         *
- * Copyright (C) 1999-2009 Daniel Diaz                                     *
+ * Copyright (C) 1999-2013 Daniel Diaz                                     *
  *                                                                         *
- * GNU Prolog is free software; you can redistribute it and/or modify it   *
- * under the terms of the GNU General Public License as published by the   *
- * Free Software Foundation; either version 2, or any later version.       *
+ * This file is part of GNU Prolog                                         *
  *                                                                         *
- * GNU Prolog is distributed in the hope that it will be useful, but       *
- * WITHOUT ANY WARRANTY; without even the implied warranty of              *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU        *
+ * GNU Prolog is free software: you can redistribute it and/or             *
+ * modify it under the terms of either:                                    *
+ *                                                                         *
+ *   - the GNU Lesser General Public License as published by the Free      *
+ *     Software Foundation; either version 3 of the License, or (at your   *
+ *     option) any later version.                                          *
+ *                                                                         *
+ * or                                                                      *
+ *                                                                         *
+ *   - the GNU General Public License as published by the Free             *
+ *     Software Foundation; either version 2 of the License, or (at your   *
+ *     option) any later version.                                          *
+ *                                                                         *
+ * or both in parallel, as here.                                           *
+ *                                                                         *
+ * GNU Prolog is distributed in the hope that it will be useful,           *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
  * General Public License for more details.                                *
  *                                                                         *
- * You should have received a copy of the GNU General Public License along *
- * with this program; if not, write to the Free Software Foundation, Inc.  *
- * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA.               *
+ * You should have received copies of the GNU General Public License and   *
+ * the GNU Lesser General Public License along with this program.  If      *
+ * not, see http://www.gnu.org/licenses/.                                  *
  *-------------------------------------------------------------------------*/
 
-/* $Id: gprolog.h,v 1.86 2009/01/23 11:24:14 diaz Exp $ */
 
 #ifndef _GPROLOG_H
 
+#include <stdint.h>
+
 #define _GPROLOG_H
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 /*
- * Since gprolog 1.3.1 all public names are prefixed with Pl_, PL_ or pl_
+ * Since GNU Prolog 1.4.0 C types 'long' have been replaced by PlLong
+ * to work on X86_64/Windows (where long are 32-bits and not 64-bits).
+ * New foreign code should use PlLong instead of long.
+ *
+ * Since GNU Prolog 1.3.1 all public names are prefixed with Pl_, PL_ or pl_
  * so you should avoid these prefixes.
  * The names of C functions used in the foreign interface have been
- * renamed to start with the Pl_ prefix. To keeb a bacward compatibility
+ * renamed to start with the Pl_ prefix. To keep a bacward compatibility
  * with foreign code developed with gprolog < 1.3.1 macros are defined
- * for old names. 
+ * for old names.
  * These macros can be deactivated if __GPROLOG_FOREIGN_STRICT__ is defined.
  *
  * #define __GPROLOG_FOREIGN_STRICT__
@@ -49,18 +67,20 @@ extern "C" {
  *---------------------------------*/
 
 
+#define __GNU_PROLOG__        	1
 #define __GPROLOG__           	1
-#define __GPROLOG_MINOR__     	3
-#define __GPROLOG_PATCHLEVEL__	1
-#define __GPROLOG_VERSION__   	10301
+#define __GPROLOG_MINOR__     	4
+#define __GPROLOG_PATCHLEVEL__	4
+#define __GPROLOG_VERSION__   	10404
 
+#define PROLOG_DIALECT  	"gprolog"
 #define PROLOG_NAME     	"GNU Prolog"
-#define PROLOG_VERSION  	"1.3.1"
-#define PROLOG_DATE     	"Feb 10 2009"
-#define PROLOG_COPYRIGHT	"Copyright (C) 1999-2009 Daniel Diaz"
+#define PROLOG_VERSION  	"1.4.4"
+#define PROLOG_DATE     	"Mar 27 2018"
+#define PROLOG_COPYRIGHT	"Copyright (C) 1999-2013 Daniel Diaz"
 
-#define PL_MIN_INTEGER		-268435456L
-#define PL_MAX_INTEGER		268435455L
+#define PL_MIN_INTEGER		-268435456
+#define PL_MAX_INTEGER		268435455
 
 #define PL_REF        		0 
 #define PL_LST        		1 
@@ -87,13 +107,19 @@ extern "C" {
 
 typedef enum { PL_FALSE, PL_TRUE } PlBool;
 
+typedef intptr_t PlLong;
+
+typedef uintptr_t PlULong;
+
+typedef intptr_t PlTerm;
+
 typedef struct
 {
   PlBool is_var;
   PlBool unify;
   union
   {
-    long l;
+    PlLong l;
     char *s;
     double d;
   }
@@ -102,9 +128,6 @@ typedef struct
 PlFIOArg;
 
 
-typedef long PlTerm;
-
-
 /*---------------------------------*
  * Global Variables                *
  *---------------------------------*/
@@ -127,7 +150,7 @@ extern int pl_type_integer;
 extern int pl_type_list;
 extern int pl_type_number;
 extern int pl_type_predicate_indicator;
-extern int pl_type_variable;
+extern int pl_type_variable;	/* deprecated: new code should emit an uninstantiation_error */
 extern int pl_type_fd_variable;
 extern int pl_type_fd_evaluable;
 extern int pl_type_fd_bool_evaluable;
@@ -266,13 +289,13 @@ PlBool Pl_Unif_With_Occurs_Check(PlTerm term1, PlTerm term2);
 
 
 
-long Pl_Rd_Integer_Check(PlTerm term);
+PlLong Pl_Rd_Integer_Check(PlTerm term);
 
-long Pl_Rd_Integer(PlTerm term);
+PlLong Pl_Rd_Integer(PlTerm term);
 
-long Pl_Rd_Positive_Check(PlTerm term);
+PlLong Pl_Rd_Positive_Check(PlTerm term);
 
-long Pl_Rd_Positive(PlTerm term);
+PlLong Pl_Rd_Positive(PlTerm term);
 
 double Pl_Rd_Float_Check(PlTerm term);
 
@@ -392,13 +415,13 @@ void Pl_Check_For_Un_Variable(PlTerm term);
 
 
 
-PlBool Pl_Un_Integer_Check(long value, PlTerm term);
+PlBool Pl_Un_Integer_Check(PlLong value, PlTerm term);
 
-PlBool Pl_Un_Integer(long value, PlTerm term);
+PlBool Pl_Un_Integer(PlLong value, PlTerm term);
 
-PlBool Pl_Un_Positive_Check(long value, PlTerm term);
+PlBool Pl_Un_Positive_Check(PlLong value, PlTerm term);
 
-PlBool Pl_Un_Positive(long value, PlTerm term);
+PlBool Pl_Un_Positive(PlLong value, PlTerm term);
 
 PlBool Pl_Un_Float_Check(double value, PlTerm term);
 
@@ -470,13 +493,13 @@ PlBool Pl_Un_Callable_Check(int func, int arity, PlTerm *arg,
 
 PlBool Pl_Un_Callable(int func, int arity, PlTerm *arg, PlTerm term);
 
-PlBool Pl_Un_Term(PlTerm term_word, PlTerm term);
+PlBool Pl_Un_Term(PlTerm term1, PlTerm term2);
 
 
 
-PlTerm Pl_Mk_Integer(long value);
+PlTerm Pl_Mk_Integer(PlLong value);
 
-PlTerm Pl_Mk_Positive(long value);
+PlTerm Pl_Mk_Positive(PlLong value);
 
 PlTerm Pl_Mk_Float(double value);
 
@@ -521,7 +544,7 @@ int Pl_Type_Of_Term(PlTerm term);
 
 int Pl_List_Length(PlTerm list);
 
-long Pl_Term_Compare(PlTerm term1, PlTerm term2);
+PlLong Pl_Term_Compare(PlTerm term1, PlTerm term2);
 
 
 
@@ -646,15 +669,30 @@ void Pl_Os_Error(void);
 
 
 
+void Pl_Write(PlTerm term);
+
+char *Pl_Write_To_String(PlTerm term);
+
+char *Pl_Writeq_To_String(PlTerm term);
+
+char *Pl_Write_Canonical_To_String(PlTerm term);
+
+char *Pl_Display_To_String(PlTerm term);
+
+PlTerm Pl_Read_From_String(const char *str);
+
+
+
 
 void Pl_Exec_Continuation(int func, int arity, PlTerm *arg_adr);
 
+void Pl_Throw(PlTerm ball);
+
 void Pl_Query_Begin(PlBool recoverable);
 
 int Pl_Query_Call(int func, int arity, PlTerm *arg_adr);
 
-#define Pl_Query_Start(func, arity, arg_adr, recoverable) \
- (Pl_Query_Begin(recoverable), Pl_Query_Call(func, arity, arg_adr))
+int Pl_Query_Start(int func, int arity, PlTerm *arg_adr, PlBool recoverable);
 
 int Pl_Query_Next_Solution(void);
 
@@ -723,7 +761,8 @@ typedef PlFIOArg FIOArg;
 #define type_list pl_type_list
 #define type_number pl_type_number
 #define type_predicate_indicator pl_type_predicate_indicator
-#define type_variable pl_type_variable
+#define type_variable pl_type_variable /* deprecated: new code should emit an uninstantiation_error */
+
 #define type_fd_variable pl_type_fd_variable
 #define type_fd_evaluable pl_type_fd_evaluable
 #define type_fd_bool_evaluable pl_type_fd_bool_evaluable
@@ -823,13 +862,13 @@ typedef PlFIOArg FIOArg;
 #define No_More_Choice()        Pl_No_More_Choice()
 
 
-#define Atom_Name(a)            Pl_Atom_Name(a)	       
-			                              
-#define Atom_Length(a)	        Pl_Atom_Length(a)	       
-			                              
-#define Atom_Needs_Quote(a)     Pl_Atom_Needs_Quote(a)    
-			                              
-#define Atom_Needs_Scan(a)      Pl_Atom_Needs_Scan(a)     
+#define Atom_Name(a)            Pl_Atom_Name(a)
+
+#define Atom_Length(a)	        Pl_Atom_Length(a)
+
+#define Atom_Needs_Quote(a)     Pl_Atom_Needs_Quote(a)
+
+#define Atom_Needs_Scan(a)      Pl_Atom_Needs_Scan(a)
 
 #define Is_Valid_Atom(a)        Pl_Is_Valid_Atom(a)
 
@@ -1053,7 +1092,7 @@ typedef PlFIOArg FIOArg;
 
 #define Un_Callable(func, arity, arg, term) Pl_Un_Callable(func, arity, arg, term)
 
-#define Un_Term(term_word, term) Pl_Un_Term(term_word, term)
+#define Un_Term(term1, term2) Pl_Un_Term(term1, term2)
 
 
 
